@@ -13,10 +13,10 @@
 #include "registercreateactionmethod.h"
 #include "kwalletmanager_debug.h"
 
+#include <kxmlgui_version.h>
 #include <KLocalizedString>
 #include <QAction>
 #include <KConfig>
-#include <KIconLoader>
 #include <KMessageBox>
 #include <KStandardAction>
 #include <KStatusNotifierItem>
@@ -154,8 +154,13 @@ void KWalletManager::configUI() {
         _tray->contextMenu()->addAction(act);
     }
     KStandardAction::quit(this, SLOT(shuttingDown()), actionCollection());
+
+#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+    KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
+#else
     KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
                                  actionCollection());
+#endif
 
     setupGUI(Keys | Save | Create, QStringLiteral("kwalletmanager.rc"));
     setStandardToolBarMenuEnabled(false);
@@ -298,7 +303,7 @@ void KWalletManager::possiblyRescan(const QString &app, const QString &oldOwner,
 void KWalletManager::createWallet()
 {
     QString txt = i18n("Please choose a name for the new wallet:");
-    QRegExpValidator validator(QRegExp(QLatin1String("^[\\w\\^\\&\\'\\@\\{\\}\\[\\]\\,\\$\\=\\!\\-\\#\\(\\)\\%\\.\\+\\_\\s]+$")), this);
+    QRegExpValidator validator(QRegExp(QLatin1String(R"(^[\w\^\&\'\@\{\}\[\]\,\$\=\!\-\#\(\)\%\.\+\_\s]+$)")), this);
 
     if (!KWallet::Wallet::isEnabled()) {
         // FIXME: KMessageBox::warningYesNo(this, i1_8n("KWallet is not enabled.  Do you want to enable it?"), QString(), i18n("Enable"), i18n("Keep Disabled"));
@@ -309,11 +314,11 @@ void KWalletManager::createWallet()
     nameDialog.setWindowTitle(i18n("New Wallet"));
     nameDialog.setLayout(new QVBoxLayout);
     nameDialog.layout()->addWidget(new QLabel(txt));
-    QLineEdit *lineEdit = new QLineEdit;
+    auto lineEdit = new QLineEdit;
     lineEdit->setValidator(&validator);
     nameDialog.layout()->addWidget(lineEdit);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     connect(buttonBox, &QDialogButtonBox::accepted, &nameDialog, &QDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, &nameDialog, &QDialog::reject);
     nameDialog.layout()->addWidget(buttonBox);
@@ -383,7 +388,7 @@ void KWalletManager::shuttingDown()
 
 void KWalletManager::setupWallet()
 {
-    auto *job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {QStringLiteral("kwalletconfig5")});
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5"), {QStringLiteral("kwalletconfig5")});
     job->start();
 }
 
